@@ -52,8 +52,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.8.0/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.8.0/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.8.1/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.8.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -626,7 +626,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.8',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
@@ -694,7 +694,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.1',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -736,9 +736,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.0 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.1 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.0 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.1 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -746,7 +746,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.8 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.8',
  'WINDOW_HAS_FLAGS': 1,
@@ -759,8 +759,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.8.0',
- 'abs_srcdir': '/build/python/src/Python-3.8.0',
+ 'abs_builddir': '/build/python/src/Python-3.8.1',
+ 'abs_srcdir': '/build/python/src/Python-3.8.1',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
